package com.ruoyi.web.controller.zdsz;

import java.util.List;
import java.util.Arrays;
import java.util.concurrent.TimeUnit;

import lombok.RequiredArgsConstructor;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.*;
import cn.dev33.satoken.annotation.SaCheckPermission;
import org.springframework.web.bind.annotation.*;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageQuery;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.vo.ZHouseVo;
import com.ruoyi.zdsz.domain.bo.ZHouseBo;
import com.ruoyi.zdsz.service.IZHouseService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 房间管理
 *
 * @author ruoyi
 * @date 2023-12-27
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/house")
public class ZHouseController extends BaseController {

    private final IZHouseService iZHouseService;

    /**
     * 查询房间管理列表
     */
    @SaCheckPermission("zdsz:house:list")
    @GetMapping("/list")
    public TableDataInfo<ZHouseVo> list(ZHouseBo bo, PageQuery pageQuery) {
        return iZHouseService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出房间管理列表
     */
    @SaCheckPermission("zdsz:house:export")
    @Log(title = "房间管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(ZHouseBo bo, HttpServletResponse response) {
        List<ZHouseVo> list = iZHouseService.queryList(bo);
        ExcelUtil.exportExcel(list, "房间管理", ZHouseVo.class, response);
    }

    /**
     * 获取房间管理详细信息
     *
     * @param id 主键
     */
    @SaCheckPermission("zdsz:house:query")
    @GetMapping("/{id}")
    public R<ZHouseVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable String id) {
        return R.ok(iZHouseService.queryById(id));
    }

    /**
     * 新增房间管理
     */
    @SaCheckPermission("zdsz:house:add")
    @Log(title = "房间管理", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody ZHouseBo bo) {
        return toAjax(iZHouseService.insertByBo(bo));
    }

    /**
     * 修改房间管理
     */
    @SaCheckPermission("zdsz:house:edit")
    @Log(title = "房间管理", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody ZHouseBo bo) {
        return toAjax(iZHouseService.updateByBo(bo));
    }

    /**
     * 删除房间管理
     *
     * @param ids 主键串
     */
    @SaCheckPermission("zdsz:house:remove")
    @Log(title = "房间管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable String[] ids) {
        return toAjax(iZHouseService.deleteWithValidByIds(Arrays.asList(ids), true));
    }
}
