package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZComprehensiveBo;
import com.ruoyi.zdsz.domain.vo.ZComprehensiveVo;
import com.ruoyi.zdsz.domain.ZComprehensive;
import com.ruoyi.zdsz.mapper.ZComprehensiveMapper;
import com.ruoyi.zdsz.service.IZComprehensiveService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 开栓|安检|维修Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-27
 */
@RequiredArgsConstructor
@Service
public class ZComprehensiveServiceImpl implements IZComprehensiveService {

    private final ZComprehensiveMapper baseMapper;

    /**
     * 查询开栓|安检|维修
     */
    @Override
    public ZComprehensiveVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询开栓|安检|维修列表
     */
    @Override
    public TableDataInfo<ZComprehensiveVo> queryPageList(ZComprehensiveBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZComprehensive> lqw = buildQueryWrapper(bo);
        Page<ZComprehensiveVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询开栓|安检|维修列表
     */
    @Override
    public List<ZComprehensiveVo> queryList(ZComprehensiveBo bo) {
        LambdaQueryWrapper<ZComprehensive> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZComprehensive> buildQueryWrapper(ZComprehensiveBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZComprehensive> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getAreaId()), ZComprehensive::getAreaId, bo.getAreaId());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildingId()), ZComprehensive::getBuildingId, bo.getBuildingId());
        lqw.eq(StringUtils.isNotBlank(bo.getUnitId()), ZComprehensive::getUnitId, bo.getUnitId());
        lqw.eq(StringUtils.isNotBlank(bo.getHouseId()), ZComprehensive::getHouseId, bo.getHouseId());
        lqw.eq(StringUtils.isNotBlank(bo.getType()), ZComprehensive::getType, bo.getType());
        lqw.eq(StringUtils.isNotBlank(bo.getIsQualified()), ZComprehensive::getIsQualified, bo.getIsQualified());
        lqw.eq(StringUtils.isNotBlank(bo.getIsMaintenance()), ZComprehensive::getIsMaintenance, bo.getIsMaintenance());
        return lqw;
    }

    /**
     * 新增开栓|安检|维修
     */
    @Override
    public Boolean insertByBo(ZComprehensiveBo bo) {
        ZComprehensive add = BeanUtil.toBean(bo, ZComprehensive.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改开栓|安检|维修
     */
    @Override
    public Boolean updateByBo(ZComprehensiveBo bo) {
        ZComprehensive update = BeanUtil.toBean(bo, ZComprehensive.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZComprehensive entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除开栓|安检|维修
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
