package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringMaterialBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringMaterialVo;
import com.ruoyi.zdsz.domain.ZEngineeringMaterial;
import com.ruoyi.zdsz.mapper.ZEngineeringMaterialMapper;
import com.ruoyi.zdsz.service.IZEngineeringMaterialService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 工程用料Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-27
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringMaterialServiceImpl implements IZEngineeringMaterialService {

    private final ZEngineeringMaterialMapper baseMapper;

    /**
     * 查询工程用料
     */
    @Override
    public ZEngineeringMaterialVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询工程用料列表
     */
    @Override
    public TableDataInfo<ZEngineeringMaterialVo> queryPageList(ZEngineeringMaterialBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringMaterial> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringMaterialVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询工程用料列表
     */
    @Override
    public List<ZEngineeringMaterialVo> queryList(ZEngineeringMaterialBo bo) {
        LambdaQueryWrapper<ZEngineeringMaterial> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringMaterial> buildQueryWrapper(ZEngineeringMaterialBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringMaterial> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getDetailsId()), ZEngineeringMaterial::getDetailsId, bo.getDetailsId());
        lqw.eq(StringUtils.isNotBlank(bo.getCorrosionLevel()), ZEngineeringMaterial::getCorrosionLevel, bo.getCorrosionLevel());
        lqw.eq(StringUtils.isNotBlank(bo.getBrand()), ZEngineeringMaterial::getBrand, bo.getBrand());
        lqw.eq(StringUtils.isNotBlank(bo.getMaterialQuality()), ZEngineeringMaterial::getMaterialQuality, bo.getMaterialQuality());
        lqw.eq(StringUtils.isNotBlank(bo.getSpecifications()), ZEngineeringMaterial::getSpecifications, bo.getSpecifications());
        lqw.eq(bo.getNumber() != null, ZEngineeringMaterial::getNumber, bo.getNumber());
        return lqw;
    }

    /**
     * 新增工程用料
     */
    @Override
    public Boolean insertByBo(ZEngineeringMaterialBo bo) {
        ZEngineeringMaterial add = BeanUtil.toBean(bo, ZEngineeringMaterial.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改工程用料
     */
    @Override
    public Boolean updateByBo(ZEngineeringMaterialBo bo) {
        ZEngineeringMaterial update = BeanUtil.toBean(bo, ZEngineeringMaterial.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringMaterial entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除工程用料
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
