package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZEngineeringReviewBo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringReviewVo;
import com.ruoyi.zdsz.domain.ZEngineeringReview;
import com.ruoyi.zdsz.mapper.ZEngineeringReviewMapper;
import com.ruoyi.zdsz.service.IZEngineeringReviewService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 工程审核Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-27
 */
@RequiredArgsConstructor
@Service
public class ZEngineeringReviewServiceImpl implements IZEngineeringReviewService {

    private final ZEngineeringReviewMapper baseMapper;

    /**
     * 查询工程审核
     */
    @Override
    public ZEngineeringReviewVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询工程审核列表
     */
    @Override
    public TableDataInfo<ZEngineeringReviewVo> queryPageList(ZEngineeringReviewBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZEngineeringReview> lqw = buildQueryWrapper(bo);
        Page<ZEngineeringReviewVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询工程审核列表
     */
    @Override
    public List<ZEngineeringReviewVo> queryList(ZEngineeringReviewBo bo) {
        LambdaQueryWrapper<ZEngineeringReview> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZEngineeringReview> buildQueryWrapper(ZEngineeringReviewBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZEngineeringReview> lqw = Wrappers.lambdaQuery();
        lqw.eq(bo.getReviewTime() != null, ZEngineeringReview::getReviewTime, bo.getReviewTime());
        lqw.eq(StringUtils.isNotBlank(bo.getReviewUser()), ZEngineeringReview::getReviewUser, bo.getReviewUser());
        lqw.eq(StringUtils.isNotBlank(bo.getReviewStatus()), ZEngineeringReview::getReviewStatus, bo.getReviewStatus());
        lqw.eq(StringUtils.isNotBlank(bo.getReviewContent()), ZEngineeringReview::getReviewContent, bo.getReviewContent());
        lqw.eq(StringUtils.isNotBlank(bo.getEngInfoId()), ZEngineeringReview::getEngInfoId, bo.getEngInfoId());
        return lqw;
    }

    /**
     * 新增工程审核
     */
    @Override
    public Boolean insertByBo(ZEngineeringReviewBo bo) {
        ZEngineeringReview add = BeanUtil.toBean(bo, ZEngineeringReview.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改工程审核
     */
    @Override
    public Boolean updateByBo(ZEngineeringReviewBo bo) {
        ZEngineeringReview update = BeanUtil.toBean(bo, ZEngineeringReview.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZEngineeringReview entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除工程审核
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
