package com.ruoyi.zdsz.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.domain.PageQuery;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;
import com.ruoyi.zdsz.domain.bo.ZUnitBo;
import com.ruoyi.zdsz.domain.vo.ZUnitVo;
import com.ruoyi.zdsz.domain.ZUnit;
import com.ruoyi.zdsz.mapper.ZUnitMapper;
import com.ruoyi.zdsz.service.IZUnitService;

import java.util.List;
import java.util.Map;
import java.util.Collection;

/**
 * 单元管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-12-27
 */
@RequiredArgsConstructor
@Service
public class ZUnitServiceImpl implements IZUnitService {

    private final ZUnitMapper baseMapper;

    /**
     * 查询单元管理
     */
    @Override
    public ZUnitVo queryById(String id){
        return baseMapper.selectVoById(id);
    }

    /**
     * 查询单元管理列表
     */
    @Override
    public TableDataInfo<ZUnitVo> queryPageList(ZUnitBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ZUnit> lqw = buildQueryWrapper(bo);
        Page<ZUnitVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询单元管理列表
     */
    @Override
    public List<ZUnitVo> queryList(ZUnitBo bo) {
        LambdaQueryWrapper<ZUnit> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ZUnit> buildQueryWrapper(ZUnitBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ZUnit> lqw = Wrappers.lambdaQuery();
        lqw.eq(StringUtils.isNotBlank(bo.getAreaId()), ZUnit::getAreaId, bo.getAreaId());
        lqw.eq(StringUtils.isNotBlank(bo.getBuildingId()), ZUnit::getBuildingId, bo.getBuildingId());
        lqw.like(StringUtils.isNotBlank(bo.getName()), ZUnit::getName, bo.getName());
        return lqw;
    }

    /**
     * 新增单元管理
     */
    @Override
    public Boolean insertByBo(ZUnitBo bo) {
        ZUnit add = BeanUtil.toBean(bo, ZUnit.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setId(add.getId());
        }
        return flag;
    }

    /**
     * 修改单元管理
     */
    @Override
    public Boolean updateByBo(ZUnitBo bo) {
        ZUnit update = BeanUtil.toBean(bo, ZUnit.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ZUnit entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 批量删除单元管理
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<String> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteBatchIds(ids) > 0;
    }
}
